# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatEditMessage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChatEditMessage.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15\x43hatEditMessage.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"h\n\x0f\x43hatEditMessage\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12\x0f\n\x07message\x18\x04 \x01(\t\"\xb9\x01\n\x17\x43hatEditMessageResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12\x17\n\x0fmessage_version\x18\x04 \x01(\x04\x12\x0f\n\x07message\x18\x05 \x01(\t\x12,\n\x0cmessage_type\x18\x06 \x01(\x0e\x32\x16.proto.RoomMessageTypeB&\n\x0enet.iGap.protoB\x14ProtoChatEditMessageb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHATEDITMESSAGE = _descriptor.Descriptor(
  name='ChatEditMessage',
  full_name='proto.ChatEditMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChatEditMessage.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatEditMessage.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChatEditMessage.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ChatEditMessage.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=181,
)


_CHATEDITMESSAGERESPONSE = _descriptor.Descriptor(
  name='ChatEditMessageResponse',
  full_name='proto.ChatEditMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChatEditMessageResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatEditMessageResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChatEditMessageResponse.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_version', full_name='proto.ChatEditMessageResponse.message_version', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ChatEditMessageResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='proto.ChatEditMessageResponse.message_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=369,
)

_CHATEDITMESSAGE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHATEDITMESSAGERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHATEDITMESSAGERESPONSE.fields_by_name['message_type'].enum_type = Global__pb2._ROOMMESSAGETYPE
DESCRIPTOR.message_types_by_name['ChatEditMessage'] = _CHATEDITMESSAGE
DESCRIPTOR.message_types_by_name['ChatEditMessageResponse'] = _CHATEDITMESSAGERESPONSE

ChatEditMessage = _reflection.GeneratedProtocolMessageType('ChatEditMessage', (_message.Message,), dict(
  DESCRIPTOR = _CHATEDITMESSAGE,
  __module__ = 'ChatEditMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatEditMessage)
  ))
_sym_db.RegisterMessage(ChatEditMessage)

ChatEditMessageResponse = _reflection.GeneratedProtocolMessageType('ChatEditMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHATEDITMESSAGERESPONSE,
  __module__ = 'ChatEditMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatEditMessageResponse)
  ))
_sym_db.RegisterMessage(ChatEditMessageResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoChatEditMessage'))
# @@protoc_insertion_point(module_scope)
