# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserPrivacySetRule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserPrivacySetRule.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18UserPrivacySetRule.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"{\n\x12UserPrivacySetRule\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.proto.PrivacyType\x12\"\n\x05level\x18\x03 \x01(\x0e\x32\x13.proto.PrivacyLevel\"\x85\x01\n\x1aUserPrivacySetRuleResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.proto.PrivacyType\x12\"\n\x05level\x18\x03 \x01(\x0e\x32\x13.proto.PrivacyLevelB)\n\x0enet.iGap.protoB\x17ProtoUserPrivacySetRuleb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERPRIVACYSETRULE = _descriptor.Descriptor(
  name='UserPrivacySetRule',
  full_name='proto.UserPrivacySetRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserPrivacySetRule.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.UserPrivacySetRule.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='proto.UserPrivacySetRule.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=203,
)


_USERPRIVACYSETRULERESPONSE = _descriptor.Descriptor(
  name='UserPrivacySetRuleResponse',
  full_name='proto.UserPrivacySetRuleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserPrivacySetRuleResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.UserPrivacySetRuleResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='proto.UserPrivacySetRuleResponse.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=339,
)

_USERPRIVACYSETRULE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERPRIVACYSETRULE.fields_by_name['type'].enum_type = Global__pb2._PRIVACYTYPE
_USERPRIVACYSETRULE.fields_by_name['level'].enum_type = Global__pb2._PRIVACYLEVEL
_USERPRIVACYSETRULERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERPRIVACYSETRULERESPONSE.fields_by_name['type'].enum_type = Global__pb2._PRIVACYTYPE
_USERPRIVACYSETRULERESPONSE.fields_by_name['level'].enum_type = Global__pb2._PRIVACYLEVEL
DESCRIPTOR.message_types_by_name['UserPrivacySetRule'] = _USERPRIVACYSETRULE
DESCRIPTOR.message_types_by_name['UserPrivacySetRuleResponse'] = _USERPRIVACYSETRULERESPONSE

UserPrivacySetRule = _reflection.GeneratedProtocolMessageType('UserPrivacySetRule', (_message.Message,), dict(
  DESCRIPTOR = _USERPRIVACYSETRULE,
  __module__ = 'UserPrivacySetRule_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserPrivacySetRule)
  ))
_sym_db.RegisterMessage(UserPrivacySetRule)

UserPrivacySetRuleResponse = _reflection.GeneratedProtocolMessageType('UserPrivacySetRuleResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERPRIVACYSETRULERESPONSE,
  __module__ = 'UserPrivacySetRule_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserPrivacySetRuleResponse)
  ))
_sym_db.RegisterMessage(UserPrivacySetRuleResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoUserPrivacySetRule'))
# @@protoc_insertion_point(module_scope)
