# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetPromote.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetPromote.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x43lientGetPromote.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"3\n\x10\x43lientGetPromote\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xed\x01\n\x18\x43lientGetPromoteResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x38\n\x07promote\x18\x02 \x03(\x0b\x32\'.proto.ClientGetPromoteResponse.Promote\x1at\n\x07Promote\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.proto.ClientGetPromoteResponse.Promote.Type\x12\n\n\x02id\x18\x02 \x01(\x04\"!\n\x04Type\x12\x08\n\x04USER\x10\x00\x12\x0f\n\x0bPUBLIC_ROOM\x10\x01\x42\'\n\x0enet.iGap.protoB\x15ProtoClientGetPromoteb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ClientGetPromoteResponse.Promote.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_ROOM', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=322,
  serialized_end=355,
)
_sym_db.RegisterEnumDescriptor(_CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE)


_CLIENTGETPROMOTE = _descriptor.Descriptor(
  name='ClientGetPromote',
  full_name='proto.ClientGetPromote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetPromote.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=115,
)


_CLIENTGETPROMOTERESPONSE_PROMOTE = _descriptor.Descriptor(
  name='Promote',
  full_name='proto.ClientGetPromoteResponse.Promote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ClientGetPromoteResponse.Promote.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.ClientGetPromoteResponse.Promote.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=355,
)

_CLIENTGETPROMOTERESPONSE = _descriptor.Descriptor(
  name='ClientGetPromoteResponse',
  full_name='proto.ClientGetPromoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetPromoteResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='promote', full_name='proto.ClientGetPromoteResponse.promote', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTGETPROMOTERESPONSE_PROMOTE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=355,
)

_CLIENTGETPROMOTE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETPROMOTERESPONSE_PROMOTE.fields_by_name['type'].enum_type = _CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE
_CLIENTGETPROMOTERESPONSE_PROMOTE.containing_type = _CLIENTGETPROMOTERESPONSE
_CLIENTGETPROMOTERESPONSE_PROMOTE_TYPE.containing_type = _CLIENTGETPROMOTERESPONSE_PROMOTE
_CLIENTGETPROMOTERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETPROMOTERESPONSE.fields_by_name['promote'].message_type = _CLIENTGETPROMOTERESPONSE_PROMOTE
DESCRIPTOR.message_types_by_name['ClientGetPromote'] = _CLIENTGETPROMOTE
DESCRIPTOR.message_types_by_name['ClientGetPromoteResponse'] = _CLIENTGETPROMOTERESPONSE

ClientGetPromote = _reflection.GeneratedProtocolMessageType('ClientGetPromote', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETPROMOTE,
  __module__ = 'ClientGetPromote_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPromote)
  ))
_sym_db.RegisterMessage(ClientGetPromote)

ClientGetPromoteResponse = _reflection.GeneratedProtocolMessageType('ClientGetPromoteResponse', (_message.Message,), dict(

  Promote = _reflection.GeneratedProtocolMessageType('Promote', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTGETPROMOTERESPONSE_PROMOTE,
    __module__ = 'ClientGetPromote_pb2'
    # @@protoc_insertion_point(class_scope:proto.ClientGetPromoteResponse.Promote)
    ))
  ,
  DESCRIPTOR = _CLIENTGETPROMOTERESPONSE,
  __module__ = 'ClientGetPromote_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPromoteResponse)
  ))
_sym_db.RegisterMessage(ClientGetPromoteResponse)
_sym_db.RegisterMessage(ClientGetPromoteResponse.Promote)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoClientGetPromote'))
# @@protoc_insertion_point(module_scope)
