# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingGetConfiguration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingGetConfiguration.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1fSignalingGetConfiguration.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"<\n\x19SignalingGetConfiguration\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xa9\x02\n!SignalingGetConfigurationResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x46\n\nice_server\x18\x02 \x03(\x0b\x32\x32.proto.SignalingGetConfigurationResponse.IceServer\x12\x15\n\rvoice_calling\x18\x03 \x01(\x08\x12\x15\n\rvideo_calling\x18\x04 \x01(\x08\x12\x16\n\x0escreen_sharing\x18\x05 \x01(\x08\x12\x13\n\x0bsecret_chat\x18\x06 \x01(\x08\x1a>\n\tIceServer\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x12\n\ncredential\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\tB0\n\x0enet.iGap.protoB\x1eProtoSignalingGetConfigurationb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SIGNALINGGETCONFIGURATION = _descriptor.Descriptor(
  name='SignalingGetConfiguration',
  full_name='proto.SignalingGetConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingGetConfiguration.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=133,
)


_SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER = _descriptor.Descriptor(
  name='IceServer',
  full_name='proto.SignalingGetConfigurationResponse.IceServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='proto.SignalingGetConfigurationResponse.IceServer.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='credential', full_name='proto.SignalingGetConfigurationResponse.IceServer.credential', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.SignalingGetConfigurationResponse.IceServer.username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=433,
)

_SIGNALINGGETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='SignalingGetConfigurationResponse',
  full_name='proto.SignalingGetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingGetConfigurationResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ice_server', full_name='proto.SignalingGetConfigurationResponse.ice_server', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voice_calling', full_name='proto.SignalingGetConfigurationResponse.voice_calling', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='video_calling', full_name='proto.SignalingGetConfigurationResponse.video_calling', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='screen_sharing', full_name='proto.SignalingGetConfigurationResponse.screen_sharing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='secret_chat', full_name='proto.SignalingGetConfigurationResponse.secret_chat', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=433,
)

_SIGNALINGGETCONFIGURATION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER.containing_type = _SIGNALINGGETCONFIGURATIONRESPONSE
_SIGNALINGGETCONFIGURATIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGGETCONFIGURATIONRESPONSE.fields_by_name['ice_server'].message_type = _SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER
DESCRIPTOR.message_types_by_name['SignalingGetConfiguration'] = _SIGNALINGGETCONFIGURATION
DESCRIPTOR.message_types_by_name['SignalingGetConfigurationResponse'] = _SIGNALINGGETCONFIGURATIONRESPONSE

SignalingGetConfiguration = _reflection.GeneratedProtocolMessageType('SignalingGetConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGGETCONFIGURATION,
  __module__ = 'SignalingGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetConfiguration)
  ))
_sym_db.RegisterMessage(SignalingGetConfiguration)

SignalingGetConfigurationResponse = _reflection.GeneratedProtocolMessageType('SignalingGetConfigurationResponse', (_message.Message,), dict(

  IceServer = _reflection.GeneratedProtocolMessageType('IceServer', (_message.Message,), dict(
    DESCRIPTOR = _SIGNALINGGETCONFIGURATIONRESPONSE_ICESERVER,
    __module__ = 'SignalingGetConfiguration_pb2'
    # @@protoc_insertion_point(class_scope:proto.SignalingGetConfigurationResponse.IceServer)
    ))
  ,
  DESCRIPTOR = _SIGNALINGGETCONFIGURATIONRESPONSE,
  __module__ = 'SignalingGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetConfigurationResponse)
  ))
_sym_db.RegisterMessage(SignalingGetConfigurationResponse)
_sym_db.RegisterMessage(SignalingGetConfigurationResponse.IceServer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\036ProtoSignalingGetConfiguration'))
# @@protoc_insertion_point(module_scope)
