# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupAddMember.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupAddMember.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14GroupAddMember.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xa5\x01\n\x0eGroupAddMember\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12,\n\x06member\x18\x03 \x01(\x0b\x32\x1c.proto.GroupAddMember.Member\x1a\x33\n\x06Member\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x18\n\x10start_message_id\x18\x02 \x01(\x04\"\x82\x01\n\x16GroupAddMemberResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12#\n\x04role\x18\x04 \x01(\x0e\x32\x15.proto.GroupRoom.RoleB%\n\x0enet.iGap.protoB\x13ProtoGroupAddMemberb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPADDMEMBER_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='proto.GroupAddMember.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupAddMember.Member.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_message_id', full_name='proto.GroupAddMember.Member.start_message_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=242,
)

_GROUPADDMEMBER = _descriptor.Descriptor(
  name='GroupAddMember',
  full_name='proto.GroupAddMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupAddMember.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddMember.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='proto.GroupAddMember.member', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPADDMEMBER_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=242,
)


_GROUPADDMEMBERRESPONSE = _descriptor.Descriptor(
  name='GroupAddMemberResponse',
  full_name='proto.GroupAddMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupAddMemberResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddMemberResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GroupAddMemberResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.GroupAddMemberResponse.role', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=375,
)

_GROUPADDMEMBER_MEMBER.containing_type = _GROUPADDMEMBER
_GROUPADDMEMBER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPADDMEMBER.fields_by_name['member'].message_type = _GROUPADDMEMBER_MEMBER
_GROUPADDMEMBERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPADDMEMBERRESPONSE.fields_by_name['role'].enum_type = Global__pb2._GROUPROOM_ROLE
DESCRIPTOR.message_types_by_name['GroupAddMember'] = _GROUPADDMEMBER
DESCRIPTOR.message_types_by_name['GroupAddMemberResponse'] = _GROUPADDMEMBERRESPONSE

GroupAddMember = _reflection.GeneratedProtocolMessageType('GroupAddMember', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _GROUPADDMEMBER_MEMBER,
    __module__ = 'GroupAddMember_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupAddMember.Member)
    ))
  ,
  DESCRIPTOR = _GROUPADDMEMBER,
  __module__ = 'GroupAddMember_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddMember)
  ))
_sym_db.RegisterMessage(GroupAddMember)
_sym_db.RegisterMessage(GroupAddMember.Member)

GroupAddMemberResponse = _reflection.GeneratedProtocolMessageType('GroupAddMemberResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPADDMEMBERRESPONSE,
  __module__ = 'GroupAddMember_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddMemberResponse)
  ))
_sym_db.RegisterMessage(GroupAddMemberResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoGroupAddMember'))
# @@protoc_insertion_point(module_scope)
