# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FileDownload.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='FileDownload.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x12\x46ileDownload.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xe9\x01\n\x0c\x46ileDownload\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x11\n\tmax_limit\x18\x04 \x01(\x05\x12.\n\x08selector\x18\x05 \x01(\x0e\x32\x1c.proto.FileDownload.Selector\"V\n\x08Selector\x12\x08\n\x04\x46ILE\x10\x00\x12\x13\n\x0fSMALL_THUMBNAIL\x10\x01\x12\x13\n\x0fLARGE_THUMBNAIL\x10\x02\x12\x16\n\x12WAVEFORM_THUMBNAIL\x10\x03\"H\n\x14\x46ileDownloadResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05\x62ytes\x18\x04 \x01(\x0c\x42#\n\x0enet.iGap.protoB\x11ProtoFileDownloadb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_FILEDOWNLOAD_SELECTOR = _descriptor.EnumDescriptor(
  name='Selector',
  full_name='proto.FileDownload.Selector',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALL_THUMBNAIL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LARGE_THUMBNAIL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_THUMBNAIL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=208,
  serialized_end=294,
)
_sym_db.RegisterEnumDescriptor(_FILEDOWNLOAD_SELECTOR)


_FILEDOWNLOAD = _descriptor.Descriptor(
  name='FileDownload',
  full_name='proto.FileDownload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.FileDownload.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.FileDownload.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='proto.FileDownload.offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_limit', full_name='proto.FileDownload.max_limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selector', full_name='proto.FileDownload.selector', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILEDOWNLOAD_SELECTOR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=294,
)


_FILEDOWNLOADRESPONSE = _descriptor.Descriptor(
  name='FileDownloadResponse',
  full_name='proto.FileDownloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.FileDownloadResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='proto.FileDownloadResponse.bytes', index=1,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=368,
)

_FILEDOWNLOAD.fields_by_name['request'].message_type = Request__pb2._REQUEST
_FILEDOWNLOAD.fields_by_name['selector'].enum_type = _FILEDOWNLOAD_SELECTOR
_FILEDOWNLOAD_SELECTOR.containing_type = _FILEDOWNLOAD
_FILEDOWNLOADRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['FileDownload'] = _FILEDOWNLOAD
DESCRIPTOR.message_types_by_name['FileDownloadResponse'] = _FILEDOWNLOADRESPONSE

FileDownload = _reflection.GeneratedProtocolMessageType('FileDownload', (_message.Message,), dict(
  DESCRIPTOR = _FILEDOWNLOAD,
  __module__ = 'FileDownload_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileDownload)
  ))
_sym_db.RegisterMessage(FileDownload)

FileDownloadResponse = _reflection.GeneratedProtocolMessageType('FileDownloadResponse', (_message.Message,), dict(
  DESCRIPTOR = _FILEDOWNLOADRESPONSE,
  __module__ = 'FileDownload_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileDownloadResponse)
  ))
_sym_db.RegisterMessage(FileDownloadResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\021ProtoFileDownload'))
# @@protoc_insertion_point(module_scope)
