# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelGetMessagesStats.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChannelGetMessagesStats.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1d\x43hannelGetMessagesStats.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"_\n\x17\x43hannelGetMessagesStats\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x03(\x04\"\xe7\x01\n\x1f\x43hannelGetMessagesStatsResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12;\n\x05stats\x18\x02 \x03(\x0b\x32,.proto.ChannelGetMessagesStatsResponse.Stats\x1a\x64\n\x05Stats\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x13\n\x0bviews_label\x18\x02 \x01(\t\x12\x17\n\x0fthumbs_up_label\x18\x03 \x01(\t\x12\x19\n\x11thumbs_down_label\x18\x04 \x01(\tB.\n\x0enet.iGap.protoB\x1cProtoChannelGetMessagesStatsb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHANNELGETMESSAGESSTATS = _descriptor.Descriptor(
  name='ChannelGetMessagesStats',
  full_name='proto.ChannelGetMessagesStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChannelGetMessagesStats.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelGetMessagesStats.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChannelGetMessagesStats.message_id', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=166,
)


_CHANNELGETMESSAGESSTATSRESPONSE_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='proto.ChannelGetMessagesStatsResponse.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.ChannelGetMessagesStatsResponse.Stats.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='views_label', full_name='proto.ChannelGetMessagesStatsResponse.Stats.views_label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thumbs_up_label', full_name='proto.ChannelGetMessagesStatsResponse.Stats.thumbs_up_label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thumbs_down_label', full_name='proto.ChannelGetMessagesStatsResponse.Stats.thumbs_down_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=400,
)

_CHANNELGETMESSAGESSTATSRESPONSE = _descriptor.Descriptor(
  name='ChannelGetMessagesStatsResponse',
  full_name='proto.ChannelGetMessagesStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChannelGetMessagesStatsResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='proto.ChannelGetMessagesStatsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELGETMESSAGESSTATSRESPONSE_STATS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=400,
)

_CHANNELGETMESSAGESSTATS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHANNELGETMESSAGESSTATSRESPONSE_STATS.containing_type = _CHANNELGETMESSAGESSTATSRESPONSE
_CHANNELGETMESSAGESSTATSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHANNELGETMESSAGESSTATSRESPONSE.fields_by_name['stats'].message_type = _CHANNELGETMESSAGESSTATSRESPONSE_STATS
DESCRIPTOR.message_types_by_name['ChannelGetMessagesStats'] = _CHANNELGETMESSAGESSTATS
DESCRIPTOR.message_types_by_name['ChannelGetMessagesStatsResponse'] = _CHANNELGETMESSAGESSTATSRESPONSE

ChannelGetMessagesStats = _reflection.GeneratedProtocolMessageType('ChannelGetMessagesStats', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELGETMESSAGESSTATS,
  __module__ = 'ChannelGetMessagesStats_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMessagesStats)
  ))
_sym_db.RegisterMessage(ChannelGetMessagesStats)

ChannelGetMessagesStatsResponse = _reflection.GeneratedProtocolMessageType('ChannelGetMessagesStatsResponse', (_message.Message,), dict(

  Stats = _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELGETMESSAGESSTATSRESPONSE_STATS,
    __module__ = 'ChannelGetMessagesStats_pb2'
    # @@protoc_insertion_point(class_scope:proto.ChannelGetMessagesStatsResponse.Stats)
    ))
  ,
  DESCRIPTOR = _CHANNELGETMESSAGESSTATSRESPONSE,
  __module__ = 'ChannelGetMessagesStats_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMessagesStatsResponse)
  ))
_sym_db.RegisterMessage(ChannelGetMessagesStatsResponse)
_sym_db.RegisterMessage(ChannelGetMessagesStatsResponse.Stats)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\034ProtoChannelGetMessagesStats'))
# @@protoc_insertion_point(module_scope)
