# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserProfileCheckUsername.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserProfileCheckUsername.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1eUserProfileCheckUsername.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"M\n\x18UserProfileCheckUsername\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x10\n\x08username\x18\x02 \x01(\t\"\xb6\x01\n UserProfileCheckUsernameResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12>\n\x06status\x18\x02 \x01(\x0e\x32..proto.UserProfileCheckUsernameResponse.Status\"/\n\x06Status\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05TAKEN\x10\x01\x12\r\n\tAVAILABLE\x10\x02\x42/\n\x0enet.iGap.protoB\x1dProtoUserProfileCheckUsernameb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERPROFILECHECKUSERNAMERESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.UserProfileCheckUsernameResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAKEN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=287,
  serialized_end=334,
)
_sym_db.RegisterEnumDescriptor(_USERPROFILECHECKUSERNAMERESPONSE_STATUS)


_USERPROFILECHECKUSERNAME = _descriptor.Descriptor(
  name='UserProfileCheckUsername',
  full_name='proto.UserProfileCheckUsername',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserProfileCheckUsername.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.UserProfileCheckUsername.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=149,
)


_USERPROFILECHECKUSERNAMERESPONSE = _descriptor.Descriptor(
  name='UserProfileCheckUsernameResponse',
  full_name='proto.UserProfileCheckUsernameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserProfileCheckUsernameResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.UserProfileCheckUsernameResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERPROFILECHECKUSERNAMERESPONSE_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=334,
)

_USERPROFILECHECKUSERNAME.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERPROFILECHECKUSERNAMERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERPROFILECHECKUSERNAMERESPONSE.fields_by_name['status'].enum_type = _USERPROFILECHECKUSERNAMERESPONSE_STATUS
_USERPROFILECHECKUSERNAMERESPONSE_STATUS.containing_type = _USERPROFILECHECKUSERNAMERESPONSE
DESCRIPTOR.message_types_by_name['UserProfileCheckUsername'] = _USERPROFILECHECKUSERNAME
DESCRIPTOR.message_types_by_name['UserProfileCheckUsernameResponse'] = _USERPROFILECHECKUSERNAMERESPONSE

UserProfileCheckUsername = _reflection.GeneratedProtocolMessageType('UserProfileCheckUsername', (_message.Message,), dict(
  DESCRIPTOR = _USERPROFILECHECKUSERNAME,
  __module__ = 'UserProfileCheckUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserProfileCheckUsername)
  ))
_sym_db.RegisterMessage(UserProfileCheckUsername)

UserProfileCheckUsernameResponse = _reflection.GeneratedProtocolMessageType('UserProfileCheckUsernameResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERPROFILECHECKUSERNAMERESPONSE,
  __module__ = 'UserProfileCheckUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserProfileCheckUsernameResponse)
  ))
_sym_db.RegisterMessage(UserProfileCheckUsernameResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\035ProtoUserProfileCheckUsername'))
# @@protoc_insertion_point(module_scope)
