# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserVerifyNewDevice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserVerifyNewDevice.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x19UserVerifyNewDevice.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"E\n\x13UserVerifyNewDevice\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05token\x18\x02 \x01(\t\"\xa2\x02\n\x1bUserVerifyNewDeviceResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x19\n\x11\x61pp_build_version\x18\x04 \x01(\r\x12\x13\n\x0b\x61pp_version\x18\x05 \x01(\t\x12!\n\x08platform\x18\x06 \x01(\x0e\x32\x0f.proto.Platform\x12\x18\n\x10platform_version\x18\x07 \x01(\t\x12\x1d\n\x06\x64\x65vice\x18\x08 \x01(\x0e\x32\r.proto.Device\x12\x13\n\x0b\x64\x65vice_name\x18\t \x01(\t\x12\x1d\n\x15two_step_verification\x18\n \x01(\x08\x42*\n\x0enet.iGap.protoB\x18ProtoUserVerifyNewDeviceb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERVERIFYNEWDEVICE = _descriptor.Descriptor(
  name='UserVerifyNewDevice',
  full_name='proto.UserVerifyNewDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserVerifyNewDevice.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.UserVerifyNewDevice.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=150,
)


_USERVERIFYNEWDEVICERESPONSE = _descriptor.Descriptor(
  name='UserVerifyNewDeviceResponse',
  full_name='proto.UserVerifyNewDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserVerifyNewDeviceResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='proto.UserVerifyNewDeviceResponse.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserVerifyNewDeviceResponse.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_build_version', full_name='proto.UserVerifyNewDeviceResponse.app_build_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='proto.UserVerifyNewDeviceResponse.app_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='proto.UserVerifyNewDeviceResponse.platform', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='proto.UserVerifyNewDeviceResponse.platform_version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='proto.UserVerifyNewDeviceResponse.device', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='proto.UserVerifyNewDeviceResponse.device_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='two_step_verification', full_name='proto.UserVerifyNewDeviceResponse.two_step_verification', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=443,
)

_USERVERIFYNEWDEVICE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERVERIFYNEWDEVICERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERVERIFYNEWDEVICERESPONSE.fields_by_name['platform'].enum_type = Global__pb2._PLATFORM
_USERVERIFYNEWDEVICERESPONSE.fields_by_name['device'].enum_type = Global__pb2._DEVICE
DESCRIPTOR.message_types_by_name['UserVerifyNewDevice'] = _USERVERIFYNEWDEVICE
DESCRIPTOR.message_types_by_name['UserVerifyNewDeviceResponse'] = _USERVERIFYNEWDEVICERESPONSE

UserVerifyNewDevice = _reflection.GeneratedProtocolMessageType('UserVerifyNewDevice', (_message.Message,), dict(
  DESCRIPTOR = _USERVERIFYNEWDEVICE,
  __module__ = 'UserVerifyNewDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserVerifyNewDevice)
  ))
_sym_db.RegisterMessage(UserVerifyNewDevice)

UserVerifyNewDeviceResponse = _reflection.GeneratedProtocolMessageType('UserVerifyNewDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERVERIFYNEWDEVICERESPONSE,
  __module__ = 'UserVerifyNewDevice_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserVerifyNewDeviceResponse)
  ))
_sym_db.RegisterMessage(UserVerifyNewDeviceResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\030ProtoUserVerifyNewDevice'))
# @@protoc_insertion_point(module_scope)
