# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserUpdateStatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserUpdateStatus.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16UserUpdateStatus.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\x86\x01\n\x10UserUpdateStatus\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.proto.UserUpdateStatus.Status\"!\n\x06Status\x12\n\n\x06ONLINE\x10\x00\x12\x0b\n\x07OFFLINE\x10\x01\"~\n\x18UserUpdateStatusResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.proto.UserUpdateStatus.Status\x12\x0f\n\x07user_id\x18\x08 \x01(\x04\x42\'\n\x0enet.iGap.protoB\x15ProtoUserUpdateStatusb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERUPDATESTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.UserUpdateStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ONLINE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFFLINE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=166,
  serialized_end=199,
)
_sym_db.RegisterEnumDescriptor(_USERUPDATESTATUS_STATUS)


_USERUPDATESTATUS = _descriptor.Descriptor(
  name='UserUpdateStatus',
  full_name='proto.UserUpdateStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserUpdateStatus.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.UserUpdateStatus.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERUPDATESTATUS_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=199,
)


_USERUPDATESTATUSRESPONSE = _descriptor.Descriptor(
  name='UserUpdateStatusResponse',
  full_name='proto.UserUpdateStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserUpdateStatusResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.UserUpdateStatusResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserUpdateStatusResponse.user_id', index=2,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=327,
)

_USERUPDATESTATUS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERUPDATESTATUS.fields_by_name['status'].enum_type = _USERUPDATESTATUS_STATUS
_USERUPDATESTATUS_STATUS.containing_type = _USERUPDATESTATUS
_USERUPDATESTATUSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERUPDATESTATUSRESPONSE.fields_by_name['status'].enum_type = _USERUPDATESTATUS_STATUS
DESCRIPTOR.message_types_by_name['UserUpdateStatus'] = _USERUPDATESTATUS
DESCRIPTOR.message_types_by_name['UserUpdateStatusResponse'] = _USERUPDATESTATUSRESPONSE

UserUpdateStatus = _reflection.GeneratedProtocolMessageType('UserUpdateStatus', (_message.Message,), dict(
  DESCRIPTOR = _USERUPDATESTATUS,
  __module__ = 'UserUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserUpdateStatus)
  ))
_sym_db.RegisterMessage(UserUpdateStatus)

UserUpdateStatusResponse = _reflection.GeneratedProtocolMessageType('UserUpdateStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERUPDATESTATUSRESPONSE,
  __module__ = 'UserUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserUpdateStatusResponse)
  ))
_sym_db.RegisterMessage(UserUpdateStatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoUserUpdateStatus'))
# @@protoc_insertion_point(module_scope)
