# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserTwoStepVerificationSetPassword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserTwoStepVerificationSetPassword.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n(UserTwoStepVerificationSetPassword.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xeb\x01\n\"UserTwoStepVerificationSetPassword\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x14\n\x0cold_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\x12\x16\n\x0erecovery_email\x18\x04 \x01(\t\x12\x14\n\x0cquestion_one\x18\x05 \x01(\t\x12\x12\n\nanswer_one\x18\x06 \x01(\t\x12\x14\n\x0cquestion_two\x18\x07 \x01(\t\x12\x12\n\nanswer_two\x18\x08 \x01(\t\x12\x0c\n\x04hint\x18\t \x01(\t\"r\n*UserTwoStepVerificationSetPasswordResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12!\n\x19unconfirmed_email_pattern\x18\x02 \x01(\tB9\n\x0enet.iGap.protoB\'ProtoUserTwoStepVerificationSetPasswordb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERTWOSTEPVERIFICATIONSETPASSWORD = _descriptor.Descriptor(
  name='UserTwoStepVerificationSetPassword',
  full_name='proto.UserTwoStepVerificationSetPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserTwoStepVerificationSetPassword.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='old_password', full_name='proto.UserTwoStepVerificationSetPassword.old_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='proto.UserTwoStepVerificationSetPassword.new_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recovery_email', full_name='proto.UserTwoStepVerificationSetPassword.recovery_email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_one', full_name='proto.UserTwoStepVerificationSetPassword.question_one', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_one', full_name='proto.UserTwoStepVerificationSetPassword.answer_one', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_two', full_name='proto.UserTwoStepVerificationSetPassword.question_two', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_two', full_name='proto.UserTwoStepVerificationSetPassword.answer_two', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hint', full_name='proto.UserTwoStepVerificationSetPassword.hint', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=318,
)


_USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='UserTwoStepVerificationSetPasswordResponse',
  full_name='proto.UserTwoStepVerificationSetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserTwoStepVerificationSetPasswordResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unconfirmed_email_pattern', full_name='proto.UserTwoStepVerificationSetPasswordResponse.unconfirmed_email_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=434,
)

_USERTWOSTEPVERIFICATIONSETPASSWORD.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationSetPassword'] = _USERTWOSTEPVERIFICATIONSETPASSWORD
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationSetPasswordResponse'] = _USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE

UserTwoStepVerificationSetPassword = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationSetPassword', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONSETPASSWORD,
  __module__ = 'UserTwoStepVerificationSetPassword_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationSetPassword)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationSetPassword)

UserTwoStepVerificationSetPasswordResponse = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationSetPasswordResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE,
  __module__ = 'UserTwoStepVerificationSetPassword_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationSetPasswordResponse)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationSetPasswordResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\'ProtoUserTwoStepVerificationSetPassword'))
# @@protoc_insertion_point(module_scope)
