# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingOffer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingOffer.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14SignalingOffer.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xda\x01\n\x0eSignalingOffer\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x16\n\x0e\x63\x61lled_user_id\x18\x02 \x01(\x04\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.proto.SignalingOffer.Type\x12\x12\n\ncaller_sdp\x18\x04 \x01(\t\"Q\n\x04Type\x12\x11\n\rVOICE_CALLING\x10\x00\x12\x11\n\rVIDEO_CALLING\x10\x01\x12\x12\n\x0eSCREEN_SHARING\x10\x02\x12\x0f\n\x0bSECRET_CHAT\x10\x03\"\x91\x01\n\x16SignalingOfferResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x16\n\x0e\x63\x61ller_user_id\x18\x02 \x01(\x04\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.proto.SignalingOffer.Type\x12\x12\n\ncaller_sdp\x18\x04 \x01(\tB%\n\x0enet.iGap.protoB\x13ProtoSignalingOfferb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SIGNALINGOFFER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.SignalingOffer.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALLING', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_CALLING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCREEN_SHARING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECRET_CHAT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=200,
  serialized_end=281,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGOFFER_TYPE)


_SIGNALINGOFFER = _descriptor.Descriptor(
  name='SignalingOffer',
  full_name='proto.SignalingOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingOffer.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='called_user_id', full_name='proto.SignalingOffer.called_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingOffer.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caller_sdp', full_name='proto.SignalingOffer.caller_sdp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGOFFER_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=281,
)


_SIGNALINGOFFERRESPONSE = _descriptor.Descriptor(
  name='SignalingOfferResponse',
  full_name='proto.SignalingOfferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingOfferResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caller_user_id', full_name='proto.SignalingOfferResponse.caller_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingOfferResponse.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caller_sdp', full_name='proto.SignalingOfferResponse.caller_sdp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=429,
)

_SIGNALINGOFFER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGOFFER.fields_by_name['type'].enum_type = _SIGNALINGOFFER_TYPE
_SIGNALINGOFFER_TYPE.containing_type = _SIGNALINGOFFER
_SIGNALINGOFFERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGOFFERRESPONSE.fields_by_name['type'].enum_type = _SIGNALINGOFFER_TYPE
DESCRIPTOR.message_types_by_name['SignalingOffer'] = _SIGNALINGOFFER
DESCRIPTOR.message_types_by_name['SignalingOfferResponse'] = _SIGNALINGOFFERRESPONSE

SignalingOffer = _reflection.GeneratedProtocolMessageType('SignalingOffer', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGOFFER,
  __module__ = 'SignalingOffer_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingOffer)
  ))
_sym_db.RegisterMessage(SignalingOffer)

SignalingOfferResponse = _reflection.GeneratedProtocolMessageType('SignalingOfferResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGOFFERRESPONSE,
  __module__ = 'SignalingOffer_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingOfferResponse)
  ))
_sym_db.RegisterMessage(SignalingOfferResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoSignalingOffer'))
# @@protoc_insertion_point(module_scope)
