# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupGetMemberList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2
from ighap_bot.proto import GroupAddAdmin_pb2 as GroupAddAdmin__pb2
from ighap_bot.proto import GroupChangeMemberRights_pb2 as GroupChangeMemberRights__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupGetMemberList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18GroupGetMemberList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\x1a\x13GroupAddAdmin.proto\x1a\x1dGroupChangeMemberRights.proto\"\xe5\x01\n\x12GroupGetMemberList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x39\n\x0b\x66ilter_role\x18\x03 \x01(\x0e\x32$.proto.GroupGetMemberList.FilterRole\x12%\n\npagination\x18\x04 \x01(\x0b\x32\x11.proto.Pagination\";\n\nFilterRole\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06MEMBER\x10\x01\x12\r\n\tMODERATOR\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\"\xb3\x02\n\x1aGroupGetMemberListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x38\n\x06member\x18\x02 \x03(\x0b\x32(.proto.GroupGetMemberListResponse.Member\x1a\xb7\x01\n\x06Member\x12\x0e\n\x06userId\x18\x01 \x01(\x04\x12#\n\x04role\x18\x02 \x01(\x0e\x32\x15.proto.GroupRoom.Role\x12\x35\n\x0b\x61\x64minRights\x18\x03 \x01(\x0b\x32 .proto.GroupAddAdmin.AdminRights\x12\x41\n\x0cmemberRights\x18\x04 \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRightsB)\n\x0enet.iGap.protoB\x17ProtoGroupGetMemberListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,GroupAddAdmin__pb2.DESCRIPTOR,GroupChangeMemberRights__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_GROUPGETMEMBERLIST_FILTERROLE = _descriptor.EnumDescriptor(
  name='FilterRole',
  full_name='proto.GroupGetMemberList.FilterRole',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODERATOR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=303,
  serialized_end=362,
)
_sym_db.RegisterEnumDescriptor(_GROUPGETMEMBERLIST_FILTERROLE)


_GROUPGETMEMBERLIST = _descriptor.Descriptor(
  name='GroupGetMemberList',
  full_name='proto.GroupGetMemberList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupGetMemberList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupGetMemberList.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_role', full_name='proto.GroupGetMemberList.filter_role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.GroupGetMemberList.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPGETMEMBERLIST_FILTERROLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=362,
)


_GROUPGETMEMBERLISTRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='proto.GroupGetMemberListResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='proto.GroupGetMemberListResponse.Member.userId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.GroupGetMemberListResponse.Member.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adminRights', full_name='proto.GroupGetMemberListResponse.Member.adminRights', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memberRights', full_name='proto.GroupGetMemberListResponse.Member.memberRights', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=672,
)

_GROUPGETMEMBERLISTRESPONSE = _descriptor.Descriptor(
  name='GroupGetMemberListResponse',
  full_name='proto.GroupGetMemberListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupGetMemberListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='proto.GroupGetMemberListResponse.member', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPGETMEMBERLISTRESPONSE_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=672,
)

_GROUPGETMEMBERLIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPGETMEMBERLIST.fields_by_name['filter_role'].enum_type = _GROUPGETMEMBERLIST_FILTERROLE
_GROUPGETMEMBERLIST.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_GROUPGETMEMBERLIST_FILTERROLE.containing_type = _GROUPGETMEMBERLIST
_GROUPGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['role'].enum_type = Global__pb2._GROUPROOM_ROLE
_GROUPGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['adminRights'].message_type = GroupAddAdmin__pb2._GROUPADDADMIN_ADMINRIGHTS
_GROUPGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['memberRights'].message_type = GroupChangeMemberRights__pb2._GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
_GROUPGETMEMBERLISTRESPONSE_MEMBER.containing_type = _GROUPGETMEMBERLISTRESPONSE
_GROUPGETMEMBERLISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPGETMEMBERLISTRESPONSE.fields_by_name['member'].message_type = _GROUPGETMEMBERLISTRESPONSE_MEMBER
DESCRIPTOR.message_types_by_name['GroupGetMemberList'] = _GROUPGETMEMBERLIST
DESCRIPTOR.message_types_by_name['GroupGetMemberListResponse'] = _GROUPGETMEMBERLISTRESPONSE

GroupGetMemberList = _reflection.GeneratedProtocolMessageType('GroupGetMemberList', (_message.Message,), dict(
  DESCRIPTOR = _GROUPGETMEMBERLIST,
  __module__ = 'GroupGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupGetMemberList)
  ))
_sym_db.RegisterMessage(GroupGetMemberList)

GroupGetMemberListResponse = _reflection.GeneratedProtocolMessageType('GroupGetMemberListResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _GROUPGETMEMBERLISTRESPONSE_MEMBER,
    __module__ = 'GroupGetMemberList_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupGetMemberListResponse.Member)
    ))
  ,
  DESCRIPTOR = _GROUPGETMEMBERLISTRESPONSE,
  __module__ = 'GroupGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupGetMemberListResponse)
  ))
_sym_db.RegisterMessage(GroupGetMemberListResponse)
_sym_db.RegisterMessage(GroupGetMemberListResponse.Member)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoGroupGetMemberList'))
# @@protoc_insertion_point(module_scope)
