# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelSendMessage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChannelSendMessage.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43hannelSendMessage.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xff\x02\n\x12\x43hannelSendMessage\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12,\n\x0cmessage_type\x18\x02 \x01(\x0e\x32\x16.proto.RoomMessageType\x12\x0f\n\x07room_id\x18\x03 \x01(\x04\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x12\n\nattachment\x18\x05 \x01(\t\x12,\n\x08location\x18\x06 \x01(\x0b\x32\x1a.proto.RoomMessageLocation\x12*\n\x07\x63ontact\x18\x07 \x01(\x0b\x32\x19.proto.RoomMessageContact\x12\x10\n\x08reply_to\x18\x08 \x01(\x04\x12\x33\n\x0c\x66orward_from\x18\t \x01(\x0b\x32\x1d.proto.RoomMessageForwardFrom\x12\x11\n\trandom_id\x18\n \x01(\x04\x12\x17\n\x0f\x61\x64\x64itional_type\x18\x0b \x01(\r\x12\x17\n\x0f\x61\x64\x64itional_data\x18\x0c \x01(\t\"z\n\x1a\x43hannelSendMessageResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12(\n\x0croom_message\x18\x03 \x01(\x0b\x32\x12.proto.RoomMessageB)\n\x0enet.iGap.protoB\x17ProtoChannelSendMessageb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHANNELSENDMESSAGE = _descriptor.Descriptor(
  name='ChannelSendMessage',
  full_name='proto.ChannelSendMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChannelSendMessage.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='proto.ChannelSendMessage.message_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelSendMessage.room_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ChannelSendMessage.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attachment', full_name='proto.ChannelSendMessage.attachment', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='proto.ChannelSendMessage.location', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact', full_name='proto.ChannelSendMessage.contact', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='proto.ChannelSendMessage.reply_to', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forward_from', full_name='proto.ChannelSendMessage.forward_from', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_id', full_name='proto.ChannelSendMessage.random_id', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_type', full_name='proto.ChannelSendMessage.additional_type', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_data', full_name='proto.ChannelSendMessage.additional_data', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=464,
)


_CHANNELSENDMESSAGERESPONSE = _descriptor.Descriptor(
  name='ChannelSendMessageResponse',
  full_name='proto.ChannelSendMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChannelSendMessageResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelSendMessageResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_message', full_name='proto.ChannelSendMessageResponse.room_message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=588,
)

_CHANNELSENDMESSAGE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHANNELSENDMESSAGE.fields_by_name['message_type'].enum_type = Global__pb2._ROOMMESSAGETYPE
_CHANNELSENDMESSAGE.fields_by_name['location'].message_type = Global__pb2._ROOMMESSAGELOCATION
_CHANNELSENDMESSAGE.fields_by_name['contact'].message_type = Global__pb2._ROOMMESSAGECONTACT
_CHANNELSENDMESSAGE.fields_by_name['forward_from'].message_type = Global__pb2._ROOMMESSAGEFORWARDFROM
_CHANNELSENDMESSAGERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHANNELSENDMESSAGERESPONSE.fields_by_name['room_message'].message_type = Global__pb2._ROOMMESSAGE
DESCRIPTOR.message_types_by_name['ChannelSendMessage'] = _CHANNELSENDMESSAGE
DESCRIPTOR.message_types_by_name['ChannelSendMessageResponse'] = _CHANNELSENDMESSAGERESPONSE

ChannelSendMessage = _reflection.GeneratedProtocolMessageType('ChannelSendMessage', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELSENDMESSAGE,
  __module__ = 'ChannelSendMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelSendMessage)
  ))
_sym_db.RegisterMessage(ChannelSendMessage)

ChannelSendMessageResponse = _reflection.GeneratedProtocolMessageType('ChannelSendMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELSENDMESSAGERESPONSE,
  __module__ = 'ChannelSendMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelSendMessageResponse)
  ))
_sym_db.RegisterMessage(ChannelSendMessageResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoChannelSendMessage'))
# @@protoc_insertion_point(module_scope)
