# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserContactsEdit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserContactsEdit.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16UserContactsEdit.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"i\n\x10UserContactsEdit\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05phone\x18\x02 \x01(\x04\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"\x85\x01\n\x18UserContactsEditResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05phone\x18\x02 \x01(\x04\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\x12\x10\n\x08initials\x18\x05 \x01(\tB\'\n\x0enet.iGap.protoB\x15ProtoUserContactsEditb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERCONTACTSEDIT = _descriptor.Descriptor(
  name='UserContactsEdit',
  full_name='proto.UserContactsEdit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserContactsEdit.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.UserContactsEdit.phone', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.UserContactsEdit.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.UserContactsEdit.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=169,
)


_USERCONTACTSEDITRESPONSE = _descriptor.Descriptor(
  name='UserContactsEditResponse',
  full_name='proto.UserContactsEditResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserContactsEditResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.UserContactsEditResponse.phone', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.UserContactsEditResponse.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.UserContactsEditResponse.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initials', full_name='proto.UserContactsEditResponse.initials', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=305,
)

_USERCONTACTSEDIT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERCONTACTSEDITRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserContactsEdit'] = _USERCONTACTSEDIT
DESCRIPTOR.message_types_by_name['UserContactsEditResponse'] = _USERCONTACTSEDITRESPONSE

UserContactsEdit = _reflection.GeneratedProtocolMessageType('UserContactsEdit', (_message.Message,), dict(
  DESCRIPTOR = _USERCONTACTSEDIT,
  __module__ = 'UserContactsEdit_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsEdit)
  ))
_sym_db.RegisterMessage(UserContactsEdit)

UserContactsEditResponse = _reflection.GeneratedProtocolMessageType('UserContactsEditResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERCONTACTSEDITRESPONSE,
  __module__ = 'UserContactsEdit_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsEditResponse)
  ))
_sym_db.RegisterMessage(UserContactsEditResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoUserContactsEdit'))
# @@protoc_insertion_point(module_scope)
