# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserIVandGetScore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserIVandGetScore.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x17UserIVandGetScore.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"4\n\x11UserIVandGetScore\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xfc\x01\n\x19UserIVandGetScoreResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05score\x18\x02 \x01(\r\x12\x11\n\tuser_rank\x18\x03 \x01(\r\x12\x12\n\ntotal_rank\x18\x04 \x01(\r\x12;\n\x06scores\x18\x05 \x03(\x0b\x32+.proto.UserIVandGetScoreResponse.IVandScore\x1aI\n\nIVandScore\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0f\n\x07\x65n_name\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x61_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\rB(\n\x0enet.iGap.protoB\x16ProtoUserIVandGetScoreb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERIVANDGETSCORE = _descriptor.Descriptor(
  name='UserIVandGetScore',
  full_name='proto.UserIVandGetScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserIVandGetScore.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=117,
)


_USERIVANDGETSCORERESPONSE_IVANDSCORE = _descriptor.Descriptor(
  name='IVandScore',
  full_name='proto.UserIVandGetScoreResponse.IVandScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.UserIVandGetScoreResponse.IVandScore.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='en_name', full_name='proto.UserIVandGetScoreResponse.IVandScore.en_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fa_name', full_name='proto.UserIVandGetScoreResponse.IVandScore.fa_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.UserIVandGetScoreResponse.IVandScore.score', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=372,
)

_USERIVANDGETSCORERESPONSE = _descriptor.Descriptor(
  name='UserIVandGetScoreResponse',
  full_name='proto.UserIVandGetScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserIVandGetScoreResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.UserIVandGetScoreResponse.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_rank', full_name='proto.UserIVandGetScoreResponse.user_rank', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_rank', full_name='proto.UserIVandGetScoreResponse.total_rank', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scores', full_name='proto.UserIVandGetScoreResponse.scores', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERIVANDGETSCORERESPONSE_IVANDSCORE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=372,
)

_USERIVANDGETSCORE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERIVANDGETSCORERESPONSE_IVANDSCORE.containing_type = _USERIVANDGETSCORERESPONSE
_USERIVANDGETSCORERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERIVANDGETSCORERESPONSE.fields_by_name['scores'].message_type = _USERIVANDGETSCORERESPONSE_IVANDSCORE
DESCRIPTOR.message_types_by_name['UserIVandGetScore'] = _USERIVANDGETSCORE
DESCRIPTOR.message_types_by_name['UserIVandGetScoreResponse'] = _USERIVANDGETSCORERESPONSE

UserIVandGetScore = _reflection.GeneratedProtocolMessageType('UserIVandGetScore', (_message.Message,), dict(
  DESCRIPTOR = _USERIVANDGETSCORE,
  __module__ = 'UserIVandGetScore_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserIVandGetScore)
  ))
_sym_db.RegisterMessage(UserIVandGetScore)

UserIVandGetScoreResponse = _reflection.GeneratedProtocolMessageType('UserIVandGetScoreResponse', (_message.Message,), dict(

  IVandScore = _reflection.GeneratedProtocolMessageType('IVandScore', (_message.Message,), dict(
    DESCRIPTOR = _USERIVANDGETSCORERESPONSE_IVANDSCORE,
    __module__ = 'UserIVandGetScore_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserIVandGetScoreResponse.IVandScore)
    ))
  ,
  DESCRIPTOR = _USERIVANDGETSCORERESPONSE,
  __module__ = 'UserIVandGetScore_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserIVandGetScoreResponse)
  ))
_sym_db.RegisterMessage(UserIVandGetScoreResponse)
_sym_db.RegisterMessage(UserIVandGetScoreResponse.IVandScore)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\026ProtoUserIVandGetScore'))
# @@protoc_insertion_point(module_scope)
