# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: QrCodeAddContact.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='QrCodeAddContact.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16QrCodeAddContact.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"i\n\x10QrCodeAddContact\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05phone\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"T\n\x18QrCodeAddContactResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x15\n\rqr_code_image\x18\x02 \x01(\x0c\x42\'\n\x0enet.iGap.protoB\x15ProtoQrCodeAddContactb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_QRCODEADDCONTACT = _descriptor.Descriptor(
  name='QrCodeAddContact',
  full_name='proto.QrCodeAddContact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.QrCodeAddContact.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.QrCodeAddContact.phone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.QrCodeAddContact.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.QrCodeAddContact.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=169,
)


_QRCODEADDCONTACTRESPONSE = _descriptor.Descriptor(
  name='QrCodeAddContactResponse',
  full_name='proto.QrCodeAddContactResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.QrCodeAddContactResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qr_code_image', full_name='proto.QrCodeAddContactResponse.qr_code_image', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=255,
)

_QRCODEADDCONTACT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_QRCODEADDCONTACTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['QrCodeAddContact'] = _QRCODEADDCONTACT
DESCRIPTOR.message_types_by_name['QrCodeAddContactResponse'] = _QRCODEADDCONTACTRESPONSE

QrCodeAddContact = _reflection.GeneratedProtocolMessageType('QrCodeAddContact', (_message.Message,), dict(
  DESCRIPTOR = _QRCODEADDCONTACT,
  __module__ = 'QrCodeAddContact_pb2'
  # @@protoc_insertion_point(class_scope:proto.QrCodeAddContact)
  ))
_sym_db.RegisterMessage(QrCodeAddContact)

QrCodeAddContactResponse = _reflection.GeneratedProtocolMessageType('QrCodeAddContactResponse', (_message.Message,), dict(
  DESCRIPTOR = _QRCODEADDCONTACTRESPONSE,
  __module__ = 'QrCodeAddContact_pb2'
  # @@protoc_insertion_point(class_scope:proto.QrCodeAddContactResponse)
  ))
_sym_db.RegisterMessage(QrCodeAddContactResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoQrCodeAddContact'))
# @@protoc_insertion_point(module_scope)
