# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingGetLog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2
from ighap_bot.proto import SignalingOffer_pb2 as SignalingOffer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingGetLog.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15SignalingGetLog.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\x1a\x14SignalingOffer.proto\"\xd1\x01\n\x0fSignalingGetLog\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12%\n\npagination\x18\x02 \x01(\x0b\x32\x11.proto.Pagination\x12-\n\x06\x66ilter\x18\x03 \x01(\x0e\x32\x1d.proto.SignalingGetLog.Filter\"G\n\x06\x46ilter\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06MISSED\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0c\n\x08INCOMING\x10\x03\x12\x0c\n\x08OUTGOING\x10\x04\"\xa6\x03\n\x17SignalingGetLogResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x42\n\rsignaling_log\x18\x02 \x03(\x0b\x32+.proto.SignalingGetLogResponse.SignalingLog\x1a\xa3\x02\n\x0cSignalingLog\x12\n\n\x02id\x18\x01 \x01(\x04\x12(\n\x04type\x18\x02 \x01(\x0e\x32\x1a.proto.SignalingOffer.Type\x12\x42\n\x06status\x18\x03 \x01(\x0e\x32\x32.proto.SignalingGetLogResponse.SignalingLog.Status\x12#\n\x04peer\x18\x04 \x01(\x0b\x32\x15.proto.RegisteredUser\x12\x12\n\noffer_time\x18\x05 \x01(\r\x12\x10\n\x08\x64uration\x18\x06 \x01(\r\x12\x0e\n\x06log_id\x18\x07 \x01(\x04\">\n\x06Status\x12\n\n\x06MISSED\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0c\n\x08INCOMING\x10\x02\x12\x0c\n\x08OUTGOING\x10\x03\x42&\n\x0enet.iGap.protoB\x14ProtoSignalingGetLogb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,SignalingOffer__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SIGNALINGGETLOG_FILTER = _descriptor.EnumDescriptor(
  name='Filter',
  full_name='proto.SignalingGetLog.Filter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMING', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTGOING', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=238,
  serialized_end=309,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGGETLOG_FILTER)

_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.SignalingGetLogResponse.SignalingLog.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTGOING', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=672,
  serialized_end=734,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS)


_SIGNALINGGETLOG = _descriptor.Descriptor(
  name='SignalingGetLog',
  full_name='proto.SignalingGetLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingGetLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.SignalingGetLog.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='proto.SignalingGetLog.filter', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGGETLOG_FILTER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=309,
)


_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG = _descriptor.Descriptor(
  name='SignalingLog',
  full_name='proto.SignalingGetLogResponse.SignalingLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.SignalingGetLogResponse.SignalingLog.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingGetLogResponse.SignalingLog.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.SignalingGetLogResponse.SignalingLog.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer', full_name='proto.SignalingGetLogResponse.SignalingLog.peer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offer_time', full_name='proto.SignalingGetLogResponse.SignalingLog.offer_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='proto.SignalingGetLogResponse.SignalingLog.duration', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='log_id', full_name='proto.SignalingGetLogResponse.SignalingLog.log_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=734,
)

_SIGNALINGGETLOGRESPONSE = _descriptor.Descriptor(
  name='SignalingGetLogResponse',
  full_name='proto.SignalingGetLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingGetLogResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signaling_log', full_name='proto.SignalingGetLogResponse.signaling_log', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=734,
)

_SIGNALINGGETLOG.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGGETLOG.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_SIGNALINGGETLOG.fields_by_name['filter'].enum_type = _SIGNALINGGETLOG_FILTER
_SIGNALINGGETLOG_FILTER.containing_type = _SIGNALINGGETLOG
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.fields_by_name['type'].enum_type = SignalingOffer__pb2._SIGNALINGOFFER_TYPE
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.fields_by_name['status'].enum_type = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.fields_by_name['peer'].message_type = Global__pb2._REGISTEREDUSER
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.containing_type = _SIGNALINGGETLOGRESPONSE
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS.containing_type = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG
_SIGNALINGGETLOGRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGGETLOGRESPONSE.fields_by_name['signaling_log'].message_type = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG
DESCRIPTOR.message_types_by_name['SignalingGetLog'] = _SIGNALINGGETLOG
DESCRIPTOR.message_types_by_name['SignalingGetLogResponse'] = _SIGNALINGGETLOGRESPONSE

SignalingGetLog = _reflection.GeneratedProtocolMessageType('SignalingGetLog', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGGETLOG,
  __module__ = 'SignalingGetLog_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetLog)
  ))
_sym_db.RegisterMessage(SignalingGetLog)

SignalingGetLogResponse = _reflection.GeneratedProtocolMessageType('SignalingGetLogResponse', (_message.Message,), dict(

  SignalingLog = _reflection.GeneratedProtocolMessageType('SignalingLog', (_message.Message,), dict(
    DESCRIPTOR = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG,
    __module__ = 'SignalingGetLog_pb2'
    # @@protoc_insertion_point(class_scope:proto.SignalingGetLogResponse.SignalingLog)
    ))
  ,
  DESCRIPTOR = _SIGNALINGGETLOGRESPONSE,
  __module__ = 'SignalingGetLog_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetLogResponse)
  ))
_sym_db.RegisterMessage(SignalingGetLogResponse)
_sym_db.RegisterMessage(SignalingGetLogResponse.SignalingLog)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoSignalingGetLog'))
# @@protoc_insertion_point(module_scope)
