# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplSalesList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplSalesList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x12MplSalesList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"}\n\x0cMplSalesList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x15.proto.MplSale.Status\x12%\n\npagination\x18\x03 \x01(\x0b\x32\x11.proto.Pagination\"W\n\x14MplSalesListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x1c\n\x04sale\x18\x02 \x03(\x0b\x32\x0e.proto.MplSaleB#\n\x0enet.iGap.protoB\x11ProtoMplSalesListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MPLSALESLIST = _descriptor.Descriptor(
  name='MplSalesList',
  full_name='proto.MplSalesList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplSalesList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplSalesList.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.MplSalesList.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=199,
)


_MPLSALESLISTRESPONSE = _descriptor.Descriptor(
  name='MplSalesListResponse',
  full_name='proto.MplSalesListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplSalesListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sale', full_name='proto.MplSalesListResponse.sale', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=288,
)

_MPLSALESLIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLSALESLIST.fields_by_name['status'].enum_type = Global__pb2._MPLSALE_STATUS
_MPLSALESLIST.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_MPLSALESLISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_MPLSALESLISTRESPONSE.fields_by_name['sale'].message_type = Global__pb2._MPLSALE
DESCRIPTOR.message_types_by_name['MplSalesList'] = _MPLSALESLIST
DESCRIPTOR.message_types_by_name['MplSalesListResponse'] = _MPLSALESLISTRESPONSE

MplSalesList = _reflection.GeneratedProtocolMessageType('MplSalesList', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESLIST,
  __module__ = 'MplSalesList_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesList)
  ))
_sym_db.RegisterMessage(MplSalesList)

MplSalesListResponse = _reflection.GeneratedProtocolMessageType('MplSalesListResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESLISTRESPONSE,
  __module__ = 'MplSalesList_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesListResponse)
  ))
_sym_db.RegisterMessage(MplSalesListResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\021ProtoMplSalesList'))
# @@protoc_insertion_point(module_scope)
