# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingLeave.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingLeave.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14SignalingLeave.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"1\n\x0eSignalingLeave\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xee\x01\n\x16SignalingLeaveResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".proto.SignalingLeaveResponse.Type\"\x7f\n\x04Type\x12\n\n\x06MISSED\x10\x00\x12\x0c\n\x08REJECTED\x10\x01\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x02\x12\x10\n\x0cNOT_ANSWERED\x10\x03\x12\x0f\n\x0bUNAVAILABLE\x10\x04\x12\x10\n\x0c\x44ISCONNECTED\x10\x05\x12\x0c\n\x08\x46INISHED\x10\x06\x12\x0c\n\x08TOO_LONG\x10\x07\x42%\n\x0enet.iGap.protoB\x13ProtoSignalingLeaveb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SIGNALINGLEAVERESPONSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.SignalingLeaveResponse.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_ANSWERED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_LONG', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=225,
  serialized_end=352,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGLEAVERESPONSE_TYPE)


_SIGNALINGLEAVE = _descriptor.Descriptor(
  name='SignalingLeave',
  full_name='proto.SignalingLeave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingLeave.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=111,
)


_SIGNALINGLEAVERESPONSE = _descriptor.Descriptor(
  name='SignalingLeaveResponse',
  full_name='proto.SignalingLeaveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingLeaveResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingLeaveResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGLEAVERESPONSE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=352,
)

_SIGNALINGLEAVE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGLEAVERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGLEAVERESPONSE.fields_by_name['type'].enum_type = _SIGNALINGLEAVERESPONSE_TYPE
_SIGNALINGLEAVERESPONSE_TYPE.containing_type = _SIGNALINGLEAVERESPONSE
DESCRIPTOR.message_types_by_name['SignalingLeave'] = _SIGNALINGLEAVE
DESCRIPTOR.message_types_by_name['SignalingLeaveResponse'] = _SIGNALINGLEAVERESPONSE

SignalingLeave = _reflection.GeneratedProtocolMessageType('SignalingLeave', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGLEAVE,
  __module__ = 'SignalingLeave_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingLeave)
  ))
_sym_db.RegisterMessage(SignalingLeave)

SignalingLeaveResponse = _reflection.GeneratedProtocolMessageType('SignalingLeaveResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGLEAVERESPONSE,
  __module__ = 'SignalingLeave_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingLeaveResponse)
  ))
_sym_db.RegisterMessage(SignalingLeaveResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoSignalingLeave'))
# @@protoc_insertion_point(module_scope)
