# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplGetSalesToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplGetSalesToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16MplGetSalesToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\x95\x01\n\x10MplGetSalesToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04\x12\x12\n\nto_user_id\x18\x03 \x01(\x04\x12\x16\n\x0einvoice_number\x18\x04 \x01(\x04\x12\x0f\n\x07inquiry\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\x82\x01\n\x18MplGetSalesTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x04 \x01(\r\x12\x0f\n\x07message\x18\x05 \x01(\tB\'\n\x0enet.iGap.protoB\x15ProtoMplGetSalesTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MPLGETSALESTOKEN = _descriptor.Descriptor(
  name='MplGetSalesToken',
  full_name='proto.MplGetSalesToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplGetSalesToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.MplGetSalesToken.amount', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='proto.MplGetSalesToken.to_user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invoice_number', full_name='proto.MplGetSalesToken.invoice_number', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inquiry', full_name='proto.MplGetSalesToken.inquiry', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.MplGetSalesToken.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=214,
)


_MPLGETSALESTOKENRESPONSE = _descriptor.Descriptor(
  name='MplGetSalesTokenResponse',
  full_name='proto.MplGetSalesTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplGetSalesTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplGetSalesTokenResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplGetSalesTokenResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.MplGetSalesTokenResponse.expire_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.MplGetSalesTokenResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=347,
)

_MPLGETSALESTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLGETSALESTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['MplGetSalesToken'] = _MPLGETSALESTOKEN
DESCRIPTOR.message_types_by_name['MplGetSalesTokenResponse'] = _MPLGETSALESTOKENRESPONSE

MplGetSalesToken = _reflection.GeneratedProtocolMessageType('MplGetSalesToken', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETSALESTOKEN,
  __module__ = 'MplGetSalesToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetSalesToken)
  ))
_sym_db.RegisterMessage(MplGetSalesToken)

MplGetSalesTokenResponse = _reflection.GeneratedProtocolMessageType('MplGetSalesTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETSALESTOKENRESPONSE,
  __module__ = 'MplGetSalesToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetSalesTokenResponse)
  ))
_sym_db.RegisterMessage(MplGetSalesTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoMplGetSalesToken'))
# @@protoc_insertion_point(module_scope)
