# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatConvertToGroup.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChatConvertToGroup.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43hatConvertToGroup.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"i\n\x12\x43hatConvertToGroup\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\x98\x01\n\x1a\x43hatConvertToGroupResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12#\n\x04role\x18\x05 \x01(\x0e\x32\x15.proto.GroupRoom.RoleB)\n\x0enet.iGap.protoB\x17ProtoChatConvertToGroupb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHATCONVERTTOGROUP = _descriptor.Descriptor(
  name='ChatConvertToGroup',
  full_name='proto.ChatConvertToGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChatConvertToGroup.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatConvertToGroup.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.ChatConvertToGroup.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ChatConvertToGroup.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=185,
)


_CHATCONVERTTOGROUPRESPONSE = _descriptor.Descriptor(
  name='ChatConvertToGroupResponse',
  full_name='proto.ChatConvertToGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChatConvertToGroupResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatConvertToGroupResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.ChatConvertToGroupResponse.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ChatConvertToGroupResponse.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.ChatConvertToGroupResponse.role', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=340,
)

_CHATCONVERTTOGROUP.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHATCONVERTTOGROUPRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHATCONVERTTOGROUPRESPONSE.fields_by_name['role'].enum_type = Global__pb2._GROUPROOM_ROLE
DESCRIPTOR.message_types_by_name['ChatConvertToGroup'] = _CHATCONVERTTOGROUP
DESCRIPTOR.message_types_by_name['ChatConvertToGroupResponse'] = _CHATCONVERTTOGROUPRESPONSE

ChatConvertToGroup = _reflection.GeneratedProtocolMessageType('ChatConvertToGroup', (_message.Message,), dict(
  DESCRIPTOR = _CHATCONVERTTOGROUP,
  __module__ = 'ChatConvertToGroup_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatConvertToGroup)
  ))
_sym_db.RegisterMessage(ChatConvertToGroup)

ChatConvertToGroupResponse = _reflection.GeneratedProtocolMessageType('ChatConvertToGroupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHATCONVERTTOGROUPRESPONSE,
  __module__ = 'ChatConvertToGroup_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatConvertToGroupResponse)
  ))
_sym_db.RegisterMessage(ChatConvertToGroupResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoChatConvertToGroup'))
# @@protoc_insertion_point(module_scope)
