# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserContactsImport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserContactsImport.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18UserContactsImport.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xe3\x01\n\x12UserContactsImport\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x33\n\x08\x63ontacts\x18\x02 \x03(\x0b\x32!.proto.UserContactsImport.Contact\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x14\n\x0c\x63ontact_hash\x18\x04 \x01(\t\x1aR\n\x07\x43ontact\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\"\xb6\x01\n\x1aUserContactsImportResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x46\n\x13registered_contacts\x18\x02 \x03(\x0b\x32).proto.UserContactsImportResponse.Contact\x1a-\n\x07\x43ontact\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x42)\n\x0enet.iGap.protoB\x17ProtoUserContactsImportb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERCONTACTSIMPORT_CONTACT = _descriptor.Descriptor(
  name='Contact',
  full_name='proto.UserContactsImport.Contact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.UserContactsImport.Contact.phone', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.UserContactsImport.Contact.first_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.UserContactsImport.Contact.last_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='proto.UserContactsImport.Contact.client_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=294,
)

_USERCONTACTSIMPORT = _descriptor.Descriptor(
  name='UserContactsImport',
  full_name='proto.UserContactsImport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserContactsImport.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contacts', full_name='proto.UserContactsImport.contacts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='force', full_name='proto.UserContactsImport.force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact_hash', full_name='proto.UserContactsImport.contact_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERCONTACTSIMPORT_CONTACT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=294,
)


_USERCONTACTSIMPORTRESPONSE_CONTACT = _descriptor.Descriptor(
  name='Contact',
  full_name='proto.UserContactsImportResponse.Contact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='proto.UserContactsImportResponse.Contact.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserContactsImportResponse.Contact.user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=479,
)

_USERCONTACTSIMPORTRESPONSE = _descriptor.Descriptor(
  name='UserContactsImportResponse',
  full_name='proto.UserContactsImportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserContactsImportResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registered_contacts', full_name='proto.UserContactsImportResponse.registered_contacts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERCONTACTSIMPORTRESPONSE_CONTACT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=479,
)

_USERCONTACTSIMPORT_CONTACT.containing_type = _USERCONTACTSIMPORT
_USERCONTACTSIMPORT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERCONTACTSIMPORT.fields_by_name['contacts'].message_type = _USERCONTACTSIMPORT_CONTACT
_USERCONTACTSIMPORTRESPONSE_CONTACT.containing_type = _USERCONTACTSIMPORTRESPONSE
_USERCONTACTSIMPORTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERCONTACTSIMPORTRESPONSE.fields_by_name['registered_contacts'].message_type = _USERCONTACTSIMPORTRESPONSE_CONTACT
DESCRIPTOR.message_types_by_name['UserContactsImport'] = _USERCONTACTSIMPORT
DESCRIPTOR.message_types_by_name['UserContactsImportResponse'] = _USERCONTACTSIMPORTRESPONSE

UserContactsImport = _reflection.GeneratedProtocolMessageType('UserContactsImport', (_message.Message,), dict(

  Contact = _reflection.GeneratedProtocolMessageType('Contact', (_message.Message,), dict(
    DESCRIPTOR = _USERCONTACTSIMPORT_CONTACT,
    __module__ = 'UserContactsImport_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserContactsImport.Contact)
    ))
  ,
  DESCRIPTOR = _USERCONTACTSIMPORT,
  __module__ = 'UserContactsImport_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsImport)
  ))
_sym_db.RegisterMessage(UserContactsImport)
_sym_db.RegisterMessage(UserContactsImport.Contact)

UserContactsImportResponse = _reflection.GeneratedProtocolMessageType('UserContactsImportResponse', (_message.Message,), dict(

  Contact = _reflection.GeneratedProtocolMessageType('Contact', (_message.Message,), dict(
    DESCRIPTOR = _USERCONTACTSIMPORTRESPONSE_CONTACT,
    __module__ = 'UserContactsImport_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserContactsImportResponse.Contact)
    ))
  ,
  DESCRIPTOR = _USERCONTACTSIMPORTRESPONSE,
  __module__ = 'UserContactsImport_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsImportResponse)
  ))
_sym_db.RegisterMessage(UserContactsImportResponse)
_sym_db.RegisterMessage(UserContactsImportResponse.Contact)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoUserContactsImport'))
# @@protoc_insertion_point(module_scope)
