# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplSalesConfirm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplSalesConfirm.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15MplSalesConfirm.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xa0\x01\n\x0fMplSalesConfirm\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x16\n\x0einvoice_number\x18\x02 \x01(\x04\x12/\n\x07\x63onfirm\x18\x03 \x01(\x0e\x32\x1e.proto.MplSalesConfirm.Confirm\"#\n\x07\x43onfirm\x12\x0b\n\x07\x43ONFIRM\x10\x00\x12\x0b\n\x07REVERSE\x10\x01\"Z\n\x17MplSalesConfirmResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x1c\n\x04sale\x18\x02 \x01(\x0b\x32\x0e.proto.MplSaleB&\n\x0enet.iGap.protoB\x14ProtoMplSalesConfirmb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_MPLSALESCONFIRM_CONFIRM = _descriptor.EnumDescriptor(
  name='Confirm',
  full_name='proto.MplSalesConfirm.Confirm',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONFIRM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVERSE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=203,
  serialized_end=238,
)
_sym_db.RegisterEnumDescriptor(_MPLSALESCONFIRM_CONFIRM)


_MPLSALESCONFIRM = _descriptor.Descriptor(
  name='MplSalesConfirm',
  full_name='proto.MplSalesConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplSalesConfirm.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invoice_number', full_name='proto.MplSalesConfirm.invoice_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confirm', full_name='proto.MplSalesConfirm.confirm', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MPLSALESCONFIRM_CONFIRM,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=238,
)


_MPLSALESCONFIRMRESPONSE = _descriptor.Descriptor(
  name='MplSalesConfirmResponse',
  full_name='proto.MplSalesConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplSalesConfirmResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sale', full_name='proto.MplSalesConfirmResponse.sale', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=330,
)

_MPLSALESCONFIRM.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLSALESCONFIRM.fields_by_name['confirm'].enum_type = _MPLSALESCONFIRM_CONFIRM
_MPLSALESCONFIRM_CONFIRM.containing_type = _MPLSALESCONFIRM
_MPLSALESCONFIRMRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_MPLSALESCONFIRMRESPONSE.fields_by_name['sale'].message_type = Global__pb2._MPLSALE
DESCRIPTOR.message_types_by_name['MplSalesConfirm'] = _MPLSALESCONFIRM
DESCRIPTOR.message_types_by_name['MplSalesConfirmResponse'] = _MPLSALESCONFIRMRESPONSE

MplSalesConfirm = _reflection.GeneratedProtocolMessageType('MplSalesConfirm', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESCONFIRM,
  __module__ = 'MplSalesConfirm_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesConfirm)
  ))
_sym_db.RegisterMessage(MplSalesConfirm)

MplSalesConfirmResponse = _reflection.GeneratedProtocolMessageType('MplSalesConfirmResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESCONFIRMRESPONSE,
  __module__ = 'MplSalesConfirm_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesConfirmResponse)
  ))
_sym_db.RegisterMessage(MplSalesConfirmResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoMplSalesConfirm'))
# @@protoc_insertion_point(module_scope)
