# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FileUploadOption.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='FileUploadOption.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x46ileUploadOption.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"A\n\x10\x46ileUploadOption\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0c\n\x04size\x18\x02 \x01(\x03\"\x8a\x01\n\x18\x46ileUploadOptionResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x19\n\x11\x66irst_bytes_limit\x18\x02 \x01(\x05\x12\x18\n\x10last_bytes_limit\x18\x03 \x01(\x05\x12\x16\n\x0emax_connection\x18\x04 \x01(\x05\x42\'\n\x0enet.iGap.protoB\x15ProtoFileUploadOptionb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_FILEUPLOADOPTION = _descriptor.Descriptor(
  name='FileUploadOption',
  full_name='proto.FileUploadOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.FileUploadOption.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.FileUploadOption.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=129,
)


_FILEUPLOADOPTIONRESPONSE = _descriptor.Descriptor(
  name='FileUploadOptionResponse',
  full_name='proto.FileUploadOptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.FileUploadOptionResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_bytes_limit', full_name='proto.FileUploadOptionResponse.first_bytes_limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_bytes_limit', full_name='proto.FileUploadOptionResponse.last_bytes_limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_connection', full_name='proto.FileUploadOptionResponse.max_connection', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=270,
)

_FILEUPLOADOPTION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_FILEUPLOADOPTIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['FileUploadOption'] = _FILEUPLOADOPTION
DESCRIPTOR.message_types_by_name['FileUploadOptionResponse'] = _FILEUPLOADOPTIONRESPONSE

FileUploadOption = _reflection.GeneratedProtocolMessageType('FileUploadOption', (_message.Message,), dict(
  DESCRIPTOR = _FILEUPLOADOPTION,
  __module__ = 'FileUploadOption_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileUploadOption)
  ))
_sym_db.RegisterMessage(FileUploadOption)

FileUploadOptionResponse = _reflection.GeneratedProtocolMessageType('FileUploadOptionResponse', (_message.Message,), dict(
  DESCRIPTOR = _FILEUPLOADOPTIONRESPONSE,
  __module__ = 'FileUploadOption_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileUploadOptionResponse)
  ))
_sym_db.RegisterMessage(FileUploadOptionResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoFileUploadOption'))
# @@protoc_insertion_point(module_scope)
