# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserSessionGetActiveList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserSessionGetActiveList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1eUserSessionGetActiveList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\";\n\x18UserSessionGetActiveList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xe5\x03\n UserSessionGetActiveListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12@\n\x07session\x18\x02 \x03(\x0b\x32/.proto.UserSessionGetActiveListResponse.Session\x1a\xdb\x02\n\x07Session\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x19\n\x11\x61pp_build_version\x18\x04 \x01(\r\x12\x13\n\x0b\x61pp_version\x18\x05 \x01(\t\x12!\n\x08platform\x18\x06 \x01(\x0e\x32\x0f.proto.Platform\x12\x18\n\x10platform_version\x18\x07 \x01(\t\x12\x1d\n\x06\x64\x65vice\x18\x08 \x01(\x0e\x32\r.proto.Device\x12\x13\n\x0b\x64\x65vice_name\x18\t \x01(\t\x12!\n\x08language\x18\n \x01(\x0e\x32\x0f.proto.Language\x12\x0f\n\x07\x63ountry\x18\x0b \x01(\t\x12\x0f\n\x07\x63urrent\x18\x0c \x01(\x08\x12\x13\n\x0b\x63reate_time\x18\r \x01(\r\x12\x13\n\x0b\x61\x63tive_time\x18\x0e \x01(\r\x12\n\n\x02ip\x18\x0f \x01(\tB/\n\x0enet.iGap.protoB\x1dProtoUserSessionGetActiveListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERSESSIONGETACTIVELIST = _descriptor.Descriptor(
  name='UserSessionGetActiveList',
  full_name='proto.UserSessionGetActiveList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserSessionGetActiveList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=145,
)


_USERSESSIONGETACTIVELISTRESPONSE_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='proto.UserSessionGetActiveListResponse.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='proto.UserSessionGetActiveListResponse.Session.session_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='proto.UserSessionGetActiveListResponse.Session.app_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserSessionGetActiveListResponse.Session.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_build_version', full_name='proto.UserSessionGetActiveListResponse.Session.app_build_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='proto.UserSessionGetActiveListResponse.Session.app_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='proto.UserSessionGetActiveListResponse.Session.platform', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='proto.UserSessionGetActiveListResponse.Session.platform_version', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='proto.UserSessionGetActiveListResponse.Session.device', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='proto.UserSessionGetActiveListResponse.Session.device_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='proto.UserSessionGetActiveListResponse.Session.language', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country', full_name='proto.UserSessionGetActiveListResponse.Session.country', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current', full_name='proto.UserSessionGetActiveListResponse.Session.current', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='proto.UserSessionGetActiveListResponse.Session.create_time', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active_time', full_name='proto.UserSessionGetActiveListResponse.Session.active_time', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='proto.UserSessionGetActiveListResponse.Session.ip', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=633,
)

_USERSESSIONGETACTIVELISTRESPONSE = _descriptor.Descriptor(
  name='UserSessionGetActiveListResponse',
  full_name='proto.UserSessionGetActiveListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserSessionGetActiveListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='session', full_name='proto.UserSessionGetActiveListResponse.session', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERSESSIONGETACTIVELISTRESPONSE_SESSION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=633,
)

_USERSESSIONGETACTIVELIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.fields_by_name['platform'].enum_type = Global__pb2._PLATFORM
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.fields_by_name['device'].enum_type = Global__pb2._DEVICE
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.fields_by_name['language'].enum_type = Global__pb2._LANGUAGE
_USERSESSIONGETACTIVELISTRESPONSE_SESSION.containing_type = _USERSESSIONGETACTIVELISTRESPONSE
_USERSESSIONGETACTIVELISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERSESSIONGETACTIVELISTRESPONSE.fields_by_name['session'].message_type = _USERSESSIONGETACTIVELISTRESPONSE_SESSION
DESCRIPTOR.message_types_by_name['UserSessionGetActiveList'] = _USERSESSIONGETACTIVELIST
DESCRIPTOR.message_types_by_name['UserSessionGetActiveListResponse'] = _USERSESSIONGETACTIVELISTRESPONSE

UserSessionGetActiveList = _reflection.GeneratedProtocolMessageType('UserSessionGetActiveList', (_message.Message,), dict(
  DESCRIPTOR = _USERSESSIONGETACTIVELIST,
  __module__ = 'UserSessionGetActiveList_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserSessionGetActiveList)
  ))
_sym_db.RegisterMessage(UserSessionGetActiveList)

UserSessionGetActiveListResponse = _reflection.GeneratedProtocolMessageType('UserSessionGetActiveListResponse', (_message.Message,), dict(

  Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), dict(
    DESCRIPTOR = _USERSESSIONGETACTIVELISTRESPONSE_SESSION,
    __module__ = 'UserSessionGetActiveList_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserSessionGetActiveListResponse.Session)
    ))
  ,
  DESCRIPTOR = _USERSESSIONGETACTIVELISTRESPONSE,
  __module__ = 'UserSessionGetActiveList_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserSessionGetActiveListResponse)
  ))
_sym_db.RegisterMessage(UserSessionGetActiveListResponse)
_sym_db.RegisterMessage(UserSessionGetActiveListResponse.Session)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\035ProtoUserSessionGetActiveList'))
# @@protoc_insertion_point(module_scope)
