# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupUpdateStatus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupUpdateStatus.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x17GroupUpdateStatus.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\x83\x01\n\x11GroupUpdateStatus\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.proto.RoomMessageStatus\"\xc2\x01\n\x19GroupUpdateStatusResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.proto.RoomMessageStatus\x12\x16\n\x0estatus_version\x18\x05 \x01(\x04\x12\x1b\n\x13updater_author_hash\x18\x06 \x01(\tB(\n\x0enet.iGap.protoB\x16ProtoGroupUpdateStatusb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPUPDATESTATUS = _descriptor.Descriptor(
  name='GroupUpdateStatus',
  full_name='proto.GroupUpdateStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupUpdateStatus.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupUpdateStatus.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.GroupUpdateStatus.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.GroupUpdateStatus.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=211,
)


_GROUPUPDATESTATUSRESPONSE = _descriptor.Descriptor(
  name='GroupUpdateStatusResponse',
  full_name='proto.GroupUpdateStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupUpdateStatusResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupUpdateStatusResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.GroupUpdateStatusResponse.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.GroupUpdateStatusResponse.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_version', full_name='proto.GroupUpdateStatusResponse.status_version', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updater_author_hash', full_name='proto.GroupUpdateStatusResponse.updater_author_hash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=408,
)

_GROUPUPDATESTATUS.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPUPDATESTATUS.fields_by_name['status'].enum_type = Global__pb2._ROOMMESSAGESTATUS
_GROUPUPDATESTATUSRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPUPDATESTATUSRESPONSE.fields_by_name['status'].enum_type = Global__pb2._ROOMMESSAGESTATUS
DESCRIPTOR.message_types_by_name['GroupUpdateStatus'] = _GROUPUPDATESTATUS
DESCRIPTOR.message_types_by_name['GroupUpdateStatusResponse'] = _GROUPUPDATESTATUSRESPONSE

GroupUpdateStatus = _reflection.GeneratedProtocolMessageType('GroupUpdateStatus', (_message.Message,), dict(
  DESCRIPTOR = _GROUPUPDATESTATUS,
  __module__ = 'GroupUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupUpdateStatus)
  ))
_sym_db.RegisterMessage(GroupUpdateStatus)

GroupUpdateStatusResponse = _reflection.GeneratedProtocolMessageType('GroupUpdateStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPUPDATESTATUSRESPONSE,
  __module__ = 'GroupUpdateStatus_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupUpdateStatusResponse)
  ))
_sym_db.RegisterMessage(GroupUpdateStatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\026ProtoGroupUpdateStatus'))
# @@protoc_insertion_point(module_scope)
