# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GeoGetConfiguration.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GeoGetConfiguration.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x19GeoGetConfiguration.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"6\n\x13GeoGetConfiguration\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xb6\x01\n\x1bGeoGetConfigurationResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x42\n\x0btile_server\x18\x02 \x03(\x0b\x32-.proto.GeoGetConfigurationResponse.TileServer\x12\x10\n\x08\x63\x61\x63he_id\x18\x03 \x01(\t\x1a\x1e\n\nTileServer\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\tB*\n\x0enet.iGap.protoB\x18ProtoGeoGetConfigurationb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GEOGETCONFIGURATION = _descriptor.Descriptor(
  name='GeoGetConfiguration',
  full_name='proto.GeoGetConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GeoGetConfiguration.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=121,
)


_GEOGETCONFIGURATIONRESPONSE_TILESERVER = _descriptor.Descriptor(
  name='TileServer',
  full_name='proto.GeoGetConfigurationResponse.TileServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_url', full_name='proto.GeoGetConfigurationResponse.TileServer.base_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=306,
)

_GEOGETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GeoGetConfigurationResponse',
  full_name='proto.GeoGetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GeoGetConfigurationResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tile_server', full_name='proto.GeoGetConfigurationResponse.tile_server', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_id', full_name='proto.GeoGetConfigurationResponse.cache_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GEOGETCONFIGURATIONRESPONSE_TILESERVER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=306,
)

_GEOGETCONFIGURATION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GEOGETCONFIGURATIONRESPONSE_TILESERVER.containing_type = _GEOGETCONFIGURATIONRESPONSE
_GEOGETCONFIGURATIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GEOGETCONFIGURATIONRESPONSE.fields_by_name['tile_server'].message_type = _GEOGETCONFIGURATIONRESPONSE_TILESERVER
DESCRIPTOR.message_types_by_name['GeoGetConfiguration'] = _GEOGETCONFIGURATION
DESCRIPTOR.message_types_by_name['GeoGetConfigurationResponse'] = _GEOGETCONFIGURATIONRESPONSE

GeoGetConfiguration = _reflection.GeneratedProtocolMessageType('GeoGetConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETCONFIGURATION,
  __module__ = 'GeoGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetConfiguration)
  ))
_sym_db.RegisterMessage(GeoGetConfiguration)

GeoGetConfigurationResponse = _reflection.GeneratedProtocolMessageType('GeoGetConfigurationResponse', (_message.Message,), dict(

  TileServer = _reflection.GeneratedProtocolMessageType('TileServer', (_message.Message,), dict(
    DESCRIPTOR = _GEOGETCONFIGURATIONRESPONSE_TILESERVER,
    __module__ = 'GeoGetConfiguration_pb2'
    # @@protoc_insertion_point(class_scope:proto.GeoGetConfigurationResponse.TileServer)
    ))
  ,
  DESCRIPTOR = _GEOGETCONFIGURATIONRESPONSE,
  __module__ = 'GeoGetConfiguration_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetConfigurationResponse)
  ))
_sym_db.RegisterMessage(GeoGetConfigurationResponse)
_sym_db.RegisterMessage(GeoGetConfigurationResponse.TileServer)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\030ProtoGeoGetConfiguration'))
# @@protoc_insertion_point(module_scope)
