# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupAddAdmin.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupAddAdmin.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x13GroupAddAdmin.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xab\x02\n\rGroupAddAdmin\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x11\n\tmember_id\x18\x03 \x01(\x04\x12\x34\n\npermission\x18\x04 \x01(\x0b\x32 .proto.GroupAddAdmin.AdminRights\x1a\x9e\x01\n\x0b\x41\x64minRights\x12\x13\n\x0bmodify_room\x18\x01 \x01(\x08\x12\x16\n\x0e\x64\x65lete_message\x18\x02 \x01(\x08\x12\x13\n\x0bpin_message\x18\x03 \x01(\x08\x12\x12\n\nadd_member\x18\x04 \x01(\x08\x12\x12\n\nban_member\x18\x05 \x01(\x08\x12\x12\n\nget_member\x18\x06 \x01(\x08\x12\x11\n\tadd_admin\x18\x07 \x01(\x08\"\x94\x01\n\x15GroupAddAdminResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x11\n\tmember_id\x18\x03 \x01(\x04\x12\x34\n\npermission\x18\x04 \x01(\x0b\x32 .proto.GroupAddAdmin.AdminRightsB$\n\x0enet.iGap.protoB\x12ProtoGroupAddAdminb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GROUPADDADMIN_ADMINRIGHTS = _descriptor.Descriptor(
  name='AdminRights',
  full_name='proto.GroupAddAdmin.AdminRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modify_room', full_name='proto.GroupAddAdmin.AdminRights.modify_room', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_message', full_name='proto.GroupAddAdmin.AdminRights.delete_message', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_message', full_name='proto.GroupAddAdmin.AdminRights.pin_message', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_member', full_name='proto.GroupAddAdmin.AdminRights.add_member', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ban_member', full_name='proto.GroupAddAdmin.AdminRights.ban_member', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get_member', full_name='proto.GroupAddAdmin.AdminRights.get_member', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_admin', full_name='proto.GroupAddAdmin.AdminRights.add_admin', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=361,
)

_GROUPADDADMIN = _descriptor.Descriptor(
  name='GroupAddAdmin',
  full_name='proto.GroupAddAdmin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupAddAdmin.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddAdmin.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='proto.GroupAddAdmin.member_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupAddAdmin.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPADDADMIN_ADMINRIGHTS, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=361,
)


_GROUPADDADMINRESPONSE = _descriptor.Descriptor(
  name='GroupAddAdminResponse',
  full_name='proto.GroupAddAdminResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupAddAdminResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupAddAdminResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='proto.GroupAddAdminResponse.member_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.GroupAddAdminResponse.permission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=512,
)

_GROUPADDADMIN_ADMINRIGHTS.containing_type = _GROUPADDADMIN
_GROUPADDADMIN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPADDADMIN.fields_by_name['permission'].message_type = _GROUPADDADMIN_ADMINRIGHTS
_GROUPADDADMINRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPADDADMINRESPONSE.fields_by_name['permission'].message_type = _GROUPADDADMIN_ADMINRIGHTS
DESCRIPTOR.message_types_by_name['GroupAddAdmin'] = _GROUPADDADMIN
DESCRIPTOR.message_types_by_name['GroupAddAdminResponse'] = _GROUPADDADMINRESPONSE

GroupAddAdmin = _reflection.GeneratedProtocolMessageType('GroupAddAdmin', (_message.Message,), dict(

  AdminRights = _reflection.GeneratedProtocolMessageType('AdminRights', (_message.Message,), dict(
    DESCRIPTOR = _GROUPADDADMIN_ADMINRIGHTS,
    __module__ = 'GroupAddAdmin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupAddAdmin.AdminRights)
    ))
  ,
  DESCRIPTOR = _GROUPADDADMIN,
  __module__ = 'GroupAddAdmin_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddAdmin)
  ))
_sym_db.RegisterMessage(GroupAddAdmin)
_sym_db.RegisterMessage(GroupAddAdmin.AdminRights)

GroupAddAdminResponse = _reflection.GeneratedProtocolMessageType('GroupAddAdminResponse', (_message.Message,), dict(
  DESCRIPTOR = _GROUPADDADMINRESPONSE,
  __module__ = 'GroupAddAdmin_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupAddAdminResponse)
  ))
_sym_db.RegisterMessage(GroupAddAdminResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\022ProtoGroupAddAdmin'))
# @@protoc_insertion_point(module_scope)
