# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientGetPoll.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientGetPoll.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x13\x43lientGetPoll.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"U\n\rClientGetPoll\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07poll_id\x18\x02 \x01(\r\x12\x12\n\nproject_id\x18\x03 \x01(\r\"e\n\x15\x43lientGetPollResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05title\x18\x02 \x01(\t\x12\x1a\n\x05polls\x18\x03 \x03(\x0b\x32\x0b.proto.PollB$\n\x0enet.iGap.protoB\x12ProtoClientGetPollb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CLIENTGETPOLL = _descriptor.Descriptor(
  name='ClientGetPoll',
  full_name='proto.ClientGetPoll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientGetPoll.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='poll_id', full_name='proto.ClientGetPoll.poll_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='proto.ClientGetPoll.project_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=160,
)


_CLIENTGETPOLLRESPONSE = _descriptor.Descriptor(
  name='ClientGetPollResponse',
  full_name='proto.ClientGetPollResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientGetPollResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.ClientGetPollResponse.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='polls', full_name='proto.ClientGetPollResponse.polls', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=263,
)

_CLIENTGETPOLL.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTGETPOLLRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTGETPOLLRESPONSE.fields_by_name['polls'].message_type = Global__pb2._POLL
DESCRIPTOR.message_types_by_name['ClientGetPoll'] = _CLIENTGETPOLL
DESCRIPTOR.message_types_by_name['ClientGetPollResponse'] = _CLIENTGETPOLLRESPONSE

ClientGetPoll = _reflection.GeneratedProtocolMessageType('ClientGetPoll', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETPOLL,
  __module__ = 'ClientGetPoll_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPoll)
  ))
_sym_db.RegisterMessage(ClientGetPoll)

ClientGetPollResponse = _reflection.GeneratedProtocolMessageType('ClientGetPollResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTGETPOLLRESPONSE,
  __module__ = 'ClientGetPoll_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientGetPollResponse)
  ))
_sym_db.RegisterMessage(ClientGetPollResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\022ProtoClientGetPoll'))
# @@protoc_insertion_point(module_scope)
