# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: WalletGetAccessToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='WalletGetAccessToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1aWalletGetAccessToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"7\n\x14WalletGetAccessToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xc7\x01\n\x1cWalletGetAccessTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x41\n\ntoken_type\x18\x02 \x01(\x0e\x32-.proto.WalletGetAccessTokenResponse.TokenType\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x12\n\nexpires_in\x18\x04 \x01(\r\"\x17\n\tTokenType\x12\n\n\x06\x42\x45\x41RER\x10\x00\x42+\n\x0enet.iGap.protoB\x19ProtoWalletGetAccessTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_WALLETGETACCESSTOKENRESPONSE_TOKENTYPE = _descriptor.EnumDescriptor(
  name='TokenType',
  full_name='proto.WalletGetAccessTokenResponse.TokenType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BEARER', index=0, number=0,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=302,
  serialized_end=325,
)
_sym_db.RegisterEnumDescriptor(_WALLETGETACCESSTOKENRESPONSE_TOKENTYPE)


_WALLETGETACCESSTOKEN = _descriptor.Descriptor(
  name='WalletGetAccessToken',
  full_name='proto.WalletGetAccessToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.WalletGetAccessToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=123,
)


_WALLETGETACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='WalletGetAccessTokenResponse',
  full_name='proto.WalletGetAccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.WalletGetAccessTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token_type', full_name='proto.WalletGetAccessTokenResponse.token_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='proto.WalletGetAccessTokenResponse.access_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='proto.WalletGetAccessTokenResponse.expires_in', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WALLETGETACCESSTOKENRESPONSE_TOKENTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=325,
)

_WALLETGETACCESSTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_WALLETGETACCESSTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_WALLETGETACCESSTOKENRESPONSE.fields_by_name['token_type'].enum_type = _WALLETGETACCESSTOKENRESPONSE_TOKENTYPE
_WALLETGETACCESSTOKENRESPONSE_TOKENTYPE.containing_type = _WALLETGETACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['WalletGetAccessToken'] = _WALLETGETACCESSTOKEN
DESCRIPTOR.message_types_by_name['WalletGetAccessTokenResponse'] = _WALLETGETACCESSTOKENRESPONSE

WalletGetAccessToken = _reflection.GeneratedProtocolMessageType('WalletGetAccessToken', (_message.Message,), dict(
  DESCRIPTOR = _WALLETGETACCESSTOKEN,
  __module__ = 'WalletGetAccessToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.WalletGetAccessToken)
  ))
_sym_db.RegisterMessage(WalletGetAccessToken)

WalletGetAccessTokenResponse = _reflection.GeneratedProtocolMessageType('WalletGetAccessTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _WALLETGETACCESSTOKENRESPONSE,
  __module__ = 'WalletGetAccessToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.WalletGetAccessTokenResponse)
  ))
_sym_db.RegisterMessage(WalletGetAccessTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoWalletGetAccessToken'))
# @@protoc_insertion_point(module_scope)
